#
#  ExternalMovieInfo - Converter
#
#  Coded by dre (c) 2014
#  Support: board.dreambox-tools.info
#
#  This converter is open source but it is NOT free software.
#
#  This converter may only be distributed to and executed on hardware which
#  is licensed by Dream Multimedia GmbH / Dream Property.
#  In other words:
#  It's NOT allowed to distribute any parts of this converter or its source code in ANY way
#  to hardware which is NOT licensed by Dream Multimedia GmbH / Dream Property.
#  It's NOT allowed to execute this converter and its source code or even parts of it in ANY way
#  on hardware which is NOT licensed by Dream Multimedia GmbH / Dream Property.

# Examples:
#        <widget position="1150,89" render="Label" size="192,25" source="session.CurrentService" transparent="1" zPosition="1">
#            <convert type="ExternalMovieInfo">Rating</convert>
#        </widget>  

#        <widget alphatest="on" pixmap="skin_default/icons/adult.png" position="240,110" render="Pixmap" size="38,31" source="session.CurrentService" zPosition="1">
#            <convert type="ExternalMovieInfo">ADULT</convert>
#            <convert type="ConditionalShowHide" />
#        </widget> 		

from Components.Converter.Converter import Converter
from Components.Element import cached, ElementError
from enigma import iServiceInformation, eServiceReference, iPlayableServicePtr
from Tools.Directories import fileExists
import json

class ExternalMovieInfo(Converter, object):
	GENRES = 0
	COUNTRIES = 1
	RELEASE = 2
	TITLE = 3
	ORIGINALTITLE = 4
	DESCRIPTION = 5
	ADULT = 6
	RATING = 7


	def __init__(self, type):
		Converter.__init__(self, type)
		if type == "Genres":
			self.type = self.GENRES
		elif type == "Countries":
			self.type = self.COUNTRIES
		elif type == "Release":
			self.type = self.RELEASE
		elif type == "Title":
			self.type = self.TITLE
		elif type == "OriginalTitle":
			self.type = self.ORIGINALTITLE
		elif type == "Description":
			self.type = self.DESCRIPTION
		elif type == "Adult":
			self.type = self.ADULT
		elif type == "Rating":
			self.type = self.RATING
		else:
			raise ElementError("'%s' is not <Genres|Countries|Release|Title|OriginalTitle|Description|Adult> for ExternalMovieInfo convertert" %(type))	

	@cached
	def getText(self):
		service = self.source.service

		extInfo = ""
		if isinstance(service, iPlayableServicePtr):
			info = service and service.info()
			serviceref = info.getInfoString(iServiceInformation.sServiceref)
			extInfo = eServiceReference(serviceref).getPath() + ".extinfo"
		
		if extInfo != "":	
			description = ""
			genrelist = []
			genres = ""
			countrylist = []
			countries = ""
			releasedate = ""
			title = ""
			originaltitle = ""
			adult = ""
			rating = ""

			if fileExists(extInfo):
				jfile = open("%s" %(extInfo),'r')
				datadict = json.loads(jfile.read())
				jfile.close()
				description = str(datadict['overview'])
				genrelist = datadict['genres']
				for genre in genrelist:
					if genres != "":
						genres += ", "
					genres += str(genre['name'])
				countrylist = datadict['production_countries']
				for country in countrylist:
					if countries != "":
						countries += ", "
					countries += str(country['iso_3166_1'])
				releasedate += "\n\n" + _("Release date: ") + str(datadict['release_date'][8:10]) + "." + str(datadict['release_date'][5:7]) + "." + str(datadict['release_date'][0:4])
				title = str(datadict['title'])
				originaltitle = str(datadict['original_title'])
				adult = str(datadict['adult'])
				rating = str(datadict['vote_average'])

				if self.type == self.GENRES:
					return genres
				if self.type == self.COUNTRIES:
					return countries
				if self.type == self.RELEASE:
					return releasedate
				if self.type == self.TITLE:
					return title
				if self.type == self.ORIGINALTITLE:
					return originaltitle
				if self.type == self.DESCRIPTION:
					return description
				if self.type == self.ADULT:
					return adult
				if self.type == self.RATING:
					return rating
		return ""
		
		@cached
	def getBool(self):
		assert self.type in (self.ADULT), "the boolean output of ExternalMovieInfo can only be used for ADULT info"
		service = self.source.service

		extInfo = ""
		if isinstance(service, iPlayableServicePtr):
			info = service and service.info()
			serviceref = info.getInfoString(iServiceInformation.sServiceref)
			extInfo = eServiceReference(serviceref).getPath() + ".extinfo"
		
		if extInfo != "":	
			adult = ""

			if fileExists(extInfo):
				jfile = open("%s" %(extInfo),'r')
				datadict = json.loads(jfile.read())
				jfile.close()
				adult = str(datadict['adult'])

				if self.type == self.ADULT:
					if adult == "true":
						return True
					else:
						return False
					return adult
		return ""
		
	text = property(getText)
	boolean = property(getBool)

	def changed(self, what):
		Converter.changed(self, what)
